@@ -30,7 +30,7 @@ class Watcher:
             await self._change_detector.queue.get()
             if self._process:
                 try:
-                    self._process.terminate()
+                    self._process.kill()
                 except ProcessLookupError:
                     # Process already finished.
                     pass
